@@ -305,18 +305,26 @@ class DojoCLI(click.MultiCommand):
 		
 		Finds all dojo instances with the state equal to inactive and force deletes them."""
 		client = prepare_docker()
-		container = client.containers.run(	
-			image = IMAGE, 
-			command=f"/bin/bash -c '/opt/kaen/dojo_prune.sh'",
-			volumes = get_volumes() ,
-			auto_remove = True,
-			detach = True )
+		vol = get_volumes()
+		env = {}
+		
+		_docker_run(client,
+					vol,
+					env,
+					f"/bin/bash -c '/opt/kaen/dojo_prune.sh'")
 
-		logs = container.attach(stream = True, logs = True)
-		for s in logs:
-			s = s.decode('utf-8').strip()
-			if len(s):
-				print(s)
+		# container = client.containers.run(	
+		# 	image = IMAGE, 
+		# 	command=f"/bin/bash -c '/opt/kaen/dojo_prune.sh'",
+		# 	volumes = get_volumes() ,
+		# 	auto_remove = True,
+		# 	detach = True )
+
+		# logs = container.attach(stream = True, logs = True)
+		# for s in logs:
+		# 	s = s.decode('utf-8').strip()
+		# 	if len(s):
+		# 		print(s)
 	
 	@click.command()
 	@click.argument('dojo')
